# SSL Metrics

> Meta package to install all `SoftwareSystemsLaboratory/ssl-metrics` packages at once

[![Release to PyPi, GitHub, and Zenodo](https://github.com/SoftwareSystemsLaboratory/ssl-metrics/actions/workflows/release.yml/badge.svg)](https://github.com/SoftwareSystemsLaboratory/ssl-metrics/actions/workflows/release.yml)

## About

This project is simply a wrapper that installs all of the other `SoftwareSystemsLaboratory/ssl-metrics` projects.

### Installed Projects

- [ssl-metrics-badges](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-badges)
- [ssl-metrics-git-bus-factor](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-bus-factor)
- [ssl-metrics-git-commits-loc](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-commits-loc)
- [ssl-metrics-git-productivity](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-productivity)
- [ssl-metrics-github-issues](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-github-issues)
- [ssl-metrics-git-commits-loc](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-commits-loc)
- [ssl-metrics-json-converter](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-json-converter)

## Getting Help

For getting help or viewing documentation of an installed program, reference it's GitHub project page
or run `PROGRAM-NAME --help` to get a list of command line options.

## How to Install

### From pip

1. Install `Python 3.9.6 +`
2. `pip install ssl-metrics-meta`
